pub enum BountyStatus<AccountId, PaymentId, Beneficiary> {
FundingAttempted {
curator: AccountId,
payment_status: PaymentState<PaymentId>,
},
Funded {
curator: AccountId,
},
CuratorUnassigned,
Active {
curator: AccountId,
},
RefundAttempted {
curator: Option<AccountId>,
payment_status: PaymentState<PaymentId>,
},
PayoutAttempted {
curator: AccountId,
beneficiary: Beneficiary,
payment_status: PaymentState<PaymentId>,
},
}Expand description
The status of a child-/bounty proposal.
Variants
FundingAttempted
The child-/bounty funding has been attempted and is waiting to confirm the funds allocation.
Call check_status to confirm whether the funding payment succeeded. If successful, the
child-/bounty transitions to BountyStatus::Funded. Otherwise, use retry_payment to
reinitiate the funding payment.
Fields
curator: AccountIdThe proposed curator of this child-/bounty.
payment_status: PaymentState<PaymentId>The funding payment status from the source (e.g. Treasury, parent bounty) to the child-/bounty account/location.
Funded
The child-/bounty is funded and waiting for curator to accept role.
Fields
curator: AccountIdThe proposed curator of this child-/bounty.
CuratorUnassigned
The child-/bounty previously assigned curator has been unassigned.
It remains funded and is waiting for a curator proposal.
Active
The child-/bounty is active and waiting to be awarded.
During the Active state, the curator can call fund_child_bounty to create multiple
child bounties.
Fields
curator: AccountIdThe curator of this child-/bounty.
RefundAttempted
The child-/bounty is closed, and the funds are being refunded to the original source (e.g.,
Treasury). Once check_status confirms the payment succeeded, the child-/bounty is
finalized and removed from storage. Otherwise, use retry_payment to reinitiate the refund
payment.
Fields
curator: Option<AccountId>The curator of this child-/bounty.
If None, it means the child-/bounty curator was unassigned.
payment_status: PaymentState<PaymentId>The refund payment status from the child-/bounty account/location to the source (e.g. Treasury, parent bounty).
PayoutAttempted
The child-/bounty payout to a beneficiary has been attempted.
Call check_status to confirm whether the payout payment succeeded. If successful, the
child-/bounty is finalized and removed from storage. Otherwise, use retry_payment to
reinitiate the payout payment.
Fields
curator: AccountIdThe curator of this child-/bounty.
beneficiary: BeneficiaryThe beneficiary stash account/location.
payment_status: PaymentState<PaymentId>The payout payment status from the child-/bounty account/location to the beneficiary.