pub type BountyOf<T, I> = Bounty<<T as Config>::AccountId, <T as Config<I>>::Balance, <T as Config<I>>::AssetKind, <T as Config>::Hash, PaymentIdOf<T, I>, <T as Config<I>>::Beneficiary>;Expand description
Convenience alias for Bounty.
Aliased Type
struct BountyOf<T, I> {
pub asset_kind: <T as Config<I>>::AssetKind,
pub value: <T as Config<I>>::Balance,
pub metadata: <T as Config>::Hash,
pub status: BountyStatus<<T as Config>::AccountId, <<T as Config<I>>::Paymaster as PayWithSource>::Id, <T as Config<I>>::Beneficiary>,
}Fields
asset_kind: <T as Config<I>>::AssetKindThe kind of asset this bounty is rewarded in.
value: <T as Config<I>>::BalanceThe amount that should be paid if the bounty is rewarded, including beneficiary payout and possible child bounties.
The asset class determined by asset_kind.
metadata: <T as Config>::HashThe metadata concerning the bounty.
The Hash refers to the preimage of the Preimages provider which can be a JSON
dump or IPFS hash of a JSON file.
status: BountyStatus<<T as Config>::AccountId, <<T as Config<I>>::Paymaster as PayWithSource>::Id, <T as Config<I>>::Beneficiary>The status of this bounty.