pub type ChildBountyOf<T, I> = ChildBounty<<T as Config>::AccountId, <T as Config<I>>::Balance, <T as Config>::Hash, PaymentIdOf<T, I>, <T as Config<I>>::Beneficiary>;Expand description
Convenience alias for ChildBounty.
Aliased Type
struct ChildBountyOf<T, I> {
pub parent_bounty: u32,
pub value: <T as Config<I>>::Balance,
pub metadata: <T as Config>::Hash,
pub status: BountyStatus<<T as Config>::AccountId, <<T as Config<I>>::Paymaster as PayWithSource>::Id, <T as Config<I>>::Beneficiary>,
}Fields
parent_bounty: u32The parent bounty index of this child-bounty.
value: <T as Config<I>>::BalanceThe amount that should be paid if the child-bounty is rewarded.
The asset class determined by the parent bounty asset_kind.
metadata: <T as Config>::HashThe metadata concerning the child-bounty.
The Hash refers to the preimage of the Preimages provider which can be a JSON
dump or IPFS hash of a JSON file.
status: BountyStatus<<T as Config>::AccountId, <<T as Config<I>>::Paymaster as PayWithSource>::Id, <T as Config<I>>::Beneficiary>The status of this child-bounty.